This is an internal function called by the download_d1_data.R function. Not to be exported
download_EML_data(data_url, meta_obj, meta_id, data_id, metadata_nodes, path)(character) An identifier or URL for a DataONE object to download.
(character) A metadata object produced by download_d1_data. This is a different format than the metadata object required for the analogous ISO function
(character) A metadata identifier produced by download_d1_data
(character) A data identifier produced by download_d1_data
(character) The member nodes where this metadata is stored, produced by download_d1_data
(character) Path to a directory to download data to.