tabularize_eml: Get tabular metadata

View source: R/tabularize_eml.R

tabularize_emlR Documentation

Get tabular metadata

Description

This function takes a path to an EML (.xml) metadata file and returns a data frame.

Usage

tabularize_eml(eml, full = FALSE)

Arguments

eml

An emld class object, the path to an EML (.xml) metadata file, or a raw EML object.

full

(logical) Returns the most commonly used metadata fields by default. If full = TRUE is specified, the full set of metadata fields are returned.

Value

(data.frame) A data frame of selected EML values.

Examples

eml <- system.file("extdata",
                   "test_data",
                   "SoilMois2012_2017__full_metadata.xml",
                   package = "metajam")
tabularize_eml(eml)

metajam documentation built on Sept. 14, 2026, 1:07 a.m.